@@ -74,7 +74,7 @@ ImageDisplay::ImageDisplay(TQObject *, const char *name, const TQStringList&)
 	
 	alpha = 0;
 	fadeTimer = new TQTimer(this);
-	connect(fadeTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(continueFade()));
+	connect(fadeTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(continueFade()));
 	
 	desktopSize = tqApp->desktop()->availableGeometry(TQCursor::pos());
 	
@@ -408,16 +408,16 @@ TQWidget * ImageDisplay::configure()
 	ImageDisplaySettings *settings = new ImageDisplaySettings();
 	
 	settings->fadeTime->setValue(fadeTime);
-	connect(settings->fadeTime, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(setFadeOut(int)));
+	connect(settings->fadeTime, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(setFadeOut(int)));
 	
 	settings->displayFont->setCurrentFont(fontFace);
-	connect(settings->displayFont, TQT_SIGNAL(textChanged(const TQString &)), this, TQT_SLOT(setFont(const TQString &)));
+	connect(settings->displayFont, TQ_SIGNAL(textChanged(const TQString &)), this, TQ_SLOT(setFont(const TQString &)));
 	
 	settings->minFontSize->setValue(minFontSize);
-	connect(settings->minFontSize, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(setMinFontSize(int)));
+	connect(settings->minFontSize, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(setMinFontSize(int)));
 	
 	settings->maxFontSize->setValue(maxFontSize);
-	connect(settings->maxFontSize, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(setMaxFontSize(int)));
+	connect(settings->maxFontSize, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(setMaxFontSize(int)));
 	
 	return settings;
 }
