@@ -322,7 +322,7 @@ TQWidget * AmarokCatalog::configure()
 	AmarokCatalogSettings *settings = new AmarokCatalogSettings();
 	
 	settings->minQueryLen->setValue(_minQueryLen);
-	connect(settings->minQueryLen, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(minQueryLenChanged(int)));
+	connect(settings->minQueryLen, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(minQueryLenChanged(int)));
 	return settings;
 }
 
