@@ -34,13 +34,13 @@
 
 Spelling::Spelling(SpellCatalog* catalog, const TQString& text): KatapultItem(), _catalog(catalog), _text(text)
 {
-	spellChecker = new KSpell( 0, "caption", this, TQT_SLOT(spellCheckerReady()) );
+	spellChecker = new KSpell( 0, "caption", this, TQ_SLOT(spellCheckerReady()) );
 
-	connect( spellChecker, TQT_SIGNAL(misspelling(const TQString&, const TQStringList&, unsigned int)),
-		 this, TQT_SLOT(spellCheckerMisspelling(const TQString&, const TQStringList&, unsigned int)) );
+	connect( spellChecker, TQ_SIGNAL(misspelling(const TQString&, const TQStringList&, unsigned int)),
+		 this, TQ_SLOT(spellCheckerMisspelling(const TQString&, const TQStringList&, unsigned int)) );
 
-	connect( spellChecker, TQT_SIGNAL(corrected(const TQString&, const TQString&, unsigned int)), 
-		 this, TQT_SLOT(spellCheckerCorrected(const TQString&, const TQString&, unsigned int)) );
+	connect( spellChecker, TQ_SIGNAL(corrected(const TQString&, const TQString&, unsigned int)), 
+		 this, TQ_SLOT(spellCheckerCorrected(const TQString&, const TQString&, unsigned int)) );
 
 	evaluate();
 }
